@@ -3,9 +3,9 @@
 use crate::counters::perf::{PerfCounter, PerfStatsRaw};
 use crate::env::RunnerEnv;
 use crate::result::{ShumaiResult, ThreadResult};
-use crate::{counters::pcm::PcmStats, BenchConfig, BenchContext, ShumaiBench};
+use crate::BenchResult;
+use crate::{counters::pcm::PcmStats, BenchConfig, Context, ShumaiBench};
 use colored::Colorize;
-use std::process;
 use std::sync::atomic::{AtomicBool, AtomicU64, Ordering};
 use std::time::{Duration, Instant};
 
@@ -17,7 +17,7 @@ impl Drop for ThreadPoison {
                 "Benchmark thread {:?} panicked, terminating all other threads...",
                 std::thread::current().id()
             );
-            process::exit(1);
+            std::process::exit(1);
         }
     }
 }
@@ -35,7 +35,7 @@ fn bench_one_sample<B: ShumaiBench>(
     crossbeam_utils::thread::scope(|scope| {
         let handlers: Vec<_> = (0..thread_cnt)
             .map(|tid| {
-                let context = BenchContext {
+                let context = Context {
                     thread_id: tid,
                     thread_cnt,
                     config,
@@ -82,8 +82,6 @@ fn bench_one_sample<B: ShumaiBench>(
 
         let start_time = Instant::now();
 
-        // TODO: we can have an async runtime here to run multiple things
-        // e.g. collecting metrics
         let mut time_cnt = 0;
         while (Instant::now() - start_time) < running_time {
             std::thread::sleep(Duration::from_millis(50));
@@ -112,9 +110,9 @@ fn bench_one_sample<B: ShumaiBench>(
         }
 
         // aggregate throughput numbers
-        let thrput = all_results
-            .iter()
-            .fold(B::Result::default(), |v, h| v + h.0.clone());
+        let thrput = all_results.iter().fold(B::Result::default(), |v, h| {
+            v + h.0.clone().normalize_time(&running_time)
+        });
 
         // aggregate perf numbers
         let perf_counter = if all_results.first().unwrap().1.is_none() {
